@@ -11,19 +11,24 @@ import (
 func ValidatePlatform(p *ovirt.Platform, fldPath *field.Path) field.ErrorList {
 	allErrs := field.ErrorList{}
 	if err := validate.UUID(p.ClusterID); err != nil {
-		allErrs = append(allErrs, field.Invalid(fldPath.Child("clusterID"), p.ClusterID, err.Error()))
+		allErrs = append(allErrs, field.Invalid(fldPath.Child("ovirt_cluster_id"), p.ClusterID, err.Error()))
 	}
 	if err := validate.UUID(p.StorageDomainID); err != nil {
-		allErrs = append(allErrs, field.Invalid(fldPath.Child("storageDomainID"), p.StorageDomainID, err.Error()))
+		allErrs = append(allErrs, field.Invalid(fldPath.Child("ovirt_storage_domain_id"), p.StorageDomainID, err.Error()))
 	}
 	if err := validate.IP(p.APIVIP); err != nil {
-		allErrs = append(allErrs, field.Invalid(fldPath.Child("apivip"), p.APIVIP, err.Error()))
+		allErrs = append(allErrs, field.Invalid(fldPath.Child("api_vip"), p.APIVIP, err.Error()))
 	}
 	if err := validate.IP(p.DNSVIP); err != nil {
-		allErrs = append(allErrs, field.Invalid(fldPath.Child("dnsvip"), p.DNSVIP, err.Error()))
+		allErrs = append(allErrs, field.Invalid(fldPath.Child("dns_vip"), p.DNSVIP, err.Error()))
 	}
 	if err := validate.IP(p.IngressVIP); err != nil {
-		allErrs = append(allErrs, field.Invalid(fldPath.Child("ingressvip"), p.IngressVIP, err.Error()))
+		allErrs = append(allErrs, field.Invalid(fldPath.Child("ingress_vip"), p.IngressVIP, err.Error()))
+	}
+	if p.VNICProfileID != "" {
+		if err := validate.UUID(p.VNICProfileID); err != nil {
+			allErrs = append(allErrs, field.Invalid(fldPath.Child("vnicProfileID"), p.IngressVIP, err.Error()))
+		}
 	}
 	if p.DefaultMachinePlatform != nil {
 		allErrs = append(allErrs, ValidateMachinePool(p.DefaultMachinePlatform, fldPath.Child("defaultMachinePlatform"))...)
